Module codec

Module codec 

Serialization strategy abstraction.

Codec converts domain events to bytes and back. SerializableEvent and ProjectionEvent are implemented by aggregate event enums to bridge the gap between domain variants and stored representations.

Enums

EventDecodeError
Error returned when deserializing a stored event fails.

Traits

Codec
Serialisation strategy used by event stores.
ProjectionEvent
Trait for event sum types that can deserialize themselves from stored events.
SerializableEvent
Trait for event sum types that can serialize themselves for persistence.