EventDecodeError

Enum EventDecodeError 

pub enum EventDecodeError<CodecError> {
    UnknownKind {
        kind: String,
        expected: &'static [&'static str],
    },
    Codec(CodecError),
}
Error returned when deserializing a stored event fails.

Variants



UnknownKind

The event kind was not recognized by this event enum.

Fields

kind: String

The unrecognized event kind string.

expected: &'static [&'static str]

The list of event kinds this enum can handle.



Codec(CodecError)

The codec failed to deserialize the event data.