pub struct PersistableEvent<M> {
pub kind: String,
pub data: Vec<u8>,
pub metadata: M,
}Expand description
Raw event data ready to be written to a store backend.
This is the boundary between Repository and EventStore. Repository
serializes events to this form, EventStore adds position and persistence.
Generic over metadata type M to support different metadata structures.
Fields
kind: Stringdata: Vec<u8>metadata: MTrait Implementations
Sourceimpl<M: Clone> Clone for PersistableEvent<M>
impl<M: Clone> Clone for PersistableEvent<M>
Sourcefn clone(&self) -> PersistableEvent<M>
fn clone(&self) -> PersistableEvent<M>
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<M> Freeze for PersistableEvent<M>where
M: Freeze,
impl<M> RefUnwindSafe for PersistableEvent<M>where
M: RefUnwindSafe,
impl<M> Send for PersistableEvent<M>where
M: Send,
impl<M> Sync for PersistableEvent<M>where
M: Sync,
impl<M> Unpin for PersistableEvent<M>where
M: Unpin,
impl<M> UnwindSafe for PersistableEvent<M>where
M: UnwindSafe,