pub trait Projection {
const KIND: &'static str;
}Expand description
Trait implemented by read models that can be constructed from an event stream.
Contains a stable KIND identifier for snapshot storage.
Projection is intentionally independent from ProjectionFilters, so
#[derive(Projection)] can always be used while filter behaviour remains an
explicit opt-in via ProjectionFilters.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.