pub struct Store<Id, Pos> { /* private fields */ }Implementations
Sourceimpl<Id, Pos> Store<Id, Pos>
impl<Id, Pos> Store<Id, Pos>
Sourcepub fn always() -> Self
pub fn always() -> Self
Create a snapshot store that saves after every command.
Best for aggregates with expensive replay or many events. See the policy guidelines above for choosing an appropriate cadence.